slapos.toolbox
==============


SlapOS toolbox contains :

- `cloudmgr <./slapos/README.cloudmgr.rst>`_
- `onetimeupload <./slapos/README.onetimeupload.rst>`_
- `webrunner <./slapos/README.webrunner.rst>`_
